
/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <errno.h>
#include <stdlib.h>
#include <string.h>

#include <debug/memory.h>
#include <debug/log.h>

#include <config/config.h>

#include <tinysnmp/compat/inttypes.h>

#include "config.h"

#define CONFIGFILE  "traffic.conf"

/* be careful not to call these functions more than 4294967295 times (; */
static uint32_t used = 0;

/* where we keep all the goodies */
static config_t config;

/*
 * parse configuration file. return a pointer to a static configuration
 * structure if successful, NULL if some error occurred. the function
 * automatically logs all errors.
 */
const config_t *config_load (const char *name,const char *path)
{
   /* increment usage count */
   used++;

   /* if its the first call, we have to load the configuration file */
   if (used == 1)
	 {
		char *filename;

		if ((filename = (char *) mem_alloc ((strlen (path) + strlen (CONFIGFILE) + 2) * sizeof (char))) == NULL)
		  {
			 log_printf (LOG_ERROR,"%s: couldn't allocate memory for temporary storage: %s\n",name,strerror (errno));
			 return (NULL);
		  }

		strcpy (filename,path);
		if (*path != '\0') strcat (filename,"/");
		strcat (filename,CONFIGFILE);

		if (!cfg_open (filename))
		  {
			 mem_free (filename);
			 return (NULL);
		  }

		mem_free (filename);

		if (!cfg_get_str (&config.socket,"socket"))
		  {
			 log_printf (LOG_ERROR,"%s: No ``socket'' string defined!\n",name);
			 cfg_close ();
			 return (NULL);
		  }

		cfg_close ();
	 }

   return (&config);
}

/*
 * free memory allocated by the config_load function.
 */
void config_close ()
{
   if (used)
	 {
		/* last guy out close the door */
		if (used == 1)
		  {
			 mem_free (config.socket);
		  }

		/* decrement usage count */
		used--;
	 }
}

