#ifndef CONFIG_H
#define CONFIG_H

/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <tinysnmp/compat/inttypes.h>
#include <abz/aton.h>

/*
 * The functions below keep a usage count which is incremented when
 * the config_load() and decremented when the config_close() is
 * called again. This ensures that the configuration file will only be
 * parsed once and only be closed after the last module is finished.
 */

typedef enum
{	/* WARNING: do not change the first two entries (unknown, total) in this enumeration */
   unknown  = 0,
   total    = 1,
   smtp     = 2,
   dns      = 3,
   http     = 4,
   pop3     = 5,
   ftp      = 6,
   ssh      = 7,
   telnet   = 8,
   tftp     = 9,
   imap     = 10,
   snmp     = 11,
   irc      = 12
} protocol_t;

typedef struct
{
   uint32_t id;						/* unique client id										*/
   char *name;						/* name of company / person								*/
   uint8_t quality;					/* service quality										*/
   uint32_t input;					/* expected incoming traffic (in bits per second)		*/
   uint32_t output;					/* expected outgoing traffic (in bits per second)		*/
   network_t *networks;				/* defined network ranges for this client				*/
   uint32_t n;						/* number of entries in list of networks				*/
} client_info_t;

typedef struct
{
   protocol_t proto;				/* protocol												*/
   int32_t rule;					/* rule number associated with this counter				*/
   uint64_t counter;				/* number of bytes counted								*/
   int valid;						/* is the counter valid?								*/
} client_counter_t;

typedef struct
{
   client_info_t info;				/* client information									*/
   client_counter_t *recv,*xmit;	/* list of counters										*/
   uint32_t n;						/* number of counters in above lists					*/
} client_t;

typedef struct
{
   char *pidfile;					/* where the process id of the daemon is stored			*/
   char *socket;					/* name of socket used for interprocess communication	*/
   uid_t uid;						/* user id of client									*/
   gid_t gid;						/* group id of client									*/
   char *interface;					/* interface on which to add accounting rules			*/
   uint16_t rulestart;				/* number of first rule to add							*/
   client_t *clients;				/* list of clients										*/
   uint32_t n;						/* number of clients in above list						*/
   uint64_t uptime;					/* timestamp of time when rules were added				*/
} traffic_t;

/*
 * parse configuration file. return 0 if successful, -1 if some error
 * occurred. the function automatically logs all errors.
 */
extern int config_load (traffic_t *traffic,const char *path);

#endif	/* #ifndef CONFIG_H */
